# v2.24.2

* added DeferredValue
* satella.coding.Context are considered experimental
* added a way to register an object to be cleaned up via MemoryPressureManager
* fixed get_own_cpu_usage() to work on Windows
* added __len__ to Optional
* major bugfix in Optional
* deprecated call_if_nnone
